
import os
import logging
import mkdocs
import mkdocs.plugins
from mkdocs.structure.files import File
from mkdocs.structure.files import get_files
import re
import string


# This global is a hack to keep track of the last time the plugin rendered diagrams.
# A global is required because plugins are reinitialized each time a change is detected.
last_run_timestamp = 0

    

    
class drawio_file_plugin(mkdocs.plugins.BasePlugin):
    config_scheme = (
        (
            "file_extension",
            mkdocs.config.config_options.Type(str, default=".drawio"),
        ),
    )

    TEMPLATE = string.Template("<div class=\"mxgraph\" style=\"max-width:100%;border:1px solid transparent;\" data-mxgraph=\"{&quot;highlight&quot;:&quot;#0000ff&quot;,&quot;nav&quot;:true,&quot;resize&quot;:true,&quot;toolbar&quot;:&quot;zoom layers tags lightbox&quot;,&quot;edit&quot;:&quot;_blank&quot;,&quot;xml&quot;:&quot;$xml_drawio&quot;}\"></div>")

    def __init__(self):
        self.log = logging.getLogger("mkdocs.plugins.diagrams")
        self.pool = None



    def escape( str_xml: str ):
        str_xml = str_xml.replace("&", "&amp;")
        str_xml = str_xml.replace("<", "&lt;")
        str_xml = str_xml.replace(">", "&gt;")
        str_xml = str_xml.replace("\"", "\&quot;")
        str_xml = str_xml.replace("'", "&apos;")
        return str_xml

    def conver_file( file_name: str):
        with open(file_name, 'r') as q_data:
            q_lines = q_data.readlines()

        drawio_text = ''.join([ item.strip() for item in q_lines])

        drawio_text_ecaped = drawio_file_plugin.escape(drawio_text)

        drawio_html = drawio_file_plugin.TEMPLATE.substitute(xml_drawio = drawio_text_ecaped )
        return drawio_html

    def convert_match(match,config,path):
        file_tag = match.group()
        file_name = file_tag[file_tag.find("(")+1:file_tag.find(")")]
        converted = drawio_file_plugin.conver_file(os.path.join(path,file_name ))
        return converted 

    def on_page_markdown(self, markdown, page,files,config) -> str:
        def file_sub(match):
            return drawio_file_plugin.convert_match(match,config,os.path.dirname(page.file.abs_src_path))

        pattern = re.compile(r'!\[(.*?)\]\((.*?.drawio)\)', flags=re.IGNORECASE)
        
        markdown = pattern.sub( file_sub, markdown)    
        markdown = markdown + "<script type=\"text/javascript\" src=\"https://viewer.diagrams.net/js/viewer-static.min.js\"></script>"
        return markdown



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['plugin']
install_requires = \
['Jinja2>=3.0.3,<4.0.0', 'requests>=2.27.1,<3.0.0']

entry_points = \
{'mkdocs.plugins': ['drawio_file = '
                    'mkdocs_drawio_file.plugin:drawio_file_plugin']}

setup_kwargs = {
    'name': 'mkdocs-drawio-file',
    'version': '1.3.0',
    'description': 'Mkdocs plugin that renders .drawio files',
    'long_description': '# Embedding files of Diagrams.net (Draw.io) into MkDocs\n\n[![](https://github.com/onixpro/mkdocs-drawio-file/workflows/Deploy/badge.svg)](https://github.com/onixpro/mkdocs-drawio-file/actions)\n[![PyPI](https://img.shields.io/pypi/v/mkdocs-drawio-file)](https://pypi.org/project/mkdocs-drawio-file/)\n\n\n\n[Buy me a 🍜](https://www.buymeacoffee.com/SergeyLukin)\n\n## Features\n\nWith the plugin configured, you can now proceed to embed images by simply embedding the `*.drawio` diagram file as you would with any image file:\n\n```markdown\n![My alt text](my-diagram.drawio)\n```\n\n\n## Dependencies\n\n## Setup\n\nInstall plugin using pip:\n\n```\npip install mkdocs-drawio-file\n```\n\nNext, add the plugin to your `mkdocs.yml`\n\n```yaml\nplugins:\n  - drawio_file\n```\n',
    'author': 'Sergey Lukin',
    'author_email': 'onixpro@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/onixpro/mkdocs-drawio-file/',
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)
